teramap demo/debug page

## Default `map_with_geojson()` map

`leaflet-scroll-intent.js` and Leaflet.fullscreen on by default.

## Different center/zoom

And a `L.contro.scale` as a bonus.

## Different layers

Adding two baselayers or 1 or more overlays will add a layers control.
leaflet-providers for a list of free tile layers.

## Adding leaflet-search and disabling Leaflet-fullscreen

leaflet-search can be anabled by adding a property.

## Adding leaflet-minimap

leaflet-search can be anabled by adding a property.

## Adding geojson

Pass the geojson object as the third argument.
Make sure to properly escape the geojson when using Django templates: `{{ geojson | safe }}`.
If a feature contains `name` property, a popup will be opened containing that name when a user clicks on the map.

## Colored markers

If a `Point` feature contains a `marker-color` property, a colored icon from leaflet-color-markers is selected (shown here are `black` and `red`, default is `blue`)

## Adding json asynchronously, with circle markers

Adding default leaflet markers is quite expensive and clutters the display. Use `circle-marker` property to display L.CircleMarker instead.

Example also shows how to load geojson asynchonously using jquery and how to add geojson to an already existing map.